package com.op.wms.mapper;

import java.util.List;

import com.op.wms.domain.SysFactory;

/**
 * 工厂模型Mapper接口
 * 
 * @author Open Platform
 * @date 2023-07-03
 */
public interface SysFactoryMapper {
	/**
	 * 查询工厂模型
	 * 
	 * @param factoryId 工厂模型主键
	 * @return 工厂模型
	 */
	public SysFactory selectSysFactoryByFactoryId(Long factoryId);

	/**
	 * 查询工厂模型列表
	 * 
	 * @param sysFactory 工厂模型
	 * @return 工厂模型集合
	 */
	public List<SysFactory> selectSysFactoryList(SysFactory sysFactory);

	/**
	 * 新增工厂模型
	 * 
	 * @param sysFactory 工厂模型
	 * @return 结果
	 */
	public int insertSysFactory(SysFactory sysFactory);

	/**
	 * 修改工厂模型
	 * 
	 * @param sysFactory 工厂模型
	 * @return 结果
	 */
	public int updateSysFactory(SysFactory sysFactory);

	/**
	 * 删除工厂模型
	 * 
	 * @param factoryId 工厂模型主键
	 * @return 结果
	 */
	public int deleteSysFactoryByFactoryId(Long factoryId);

	/**
	 * 批量删除工厂模型
	 * 
	 * @param factoryIds 需要删除的数据主键集合
	 * @return 结果
	 */
	public int deleteSysFactoryByFactoryIds(Long[] factoryIds);
}
